SSM (Unified Interface)
=======================

A unified high-level interface for both linear and nonlinear state-space
models, with automatic filter selection.

.. autoclass:: dynaris.core.ssm.SSM
   :members:
   :show-inheritance:
